===========================
 Invenio-Classifier v1.1.0
===========================

Incompatible changes
--------------------

- Changes dict export format for author keywords, into an improved and semantic
  way.
- Renames keys in dict export to be lower case and separated by `_`.

Bug fixes
---------

- Drop trailing dots in author keywords.

Installation
------------

   $ pip install invenio-classifier==0.1.0

Documentation
-------------

   http://invenio-classifier.readthedocs.org/en/v0.1.0

Happy hacking and thanks for flying Invenio-Classifier.

| Inspirehep Development Team
|   Email: admin@inspirehep.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware-contrib/invenio-classifier
|   URL: http://inveniosoftware.org
